#
# spec file for package qucs
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           qucs
Version:        0.0.19
Release:        14.11
Summary:        Circuit Simulator with Graphical User Interface (Qt)
License:        GPL-2.0-only AND GPL-2.0-or-later
Group:          Productivity/Scientific/Electronics
Url:            http://qucs.sf.net
Source0:        https://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE qucs-0.0.19-desktop-category.patch -- Respect openSUSE's own desktop categories
Patch0:         qucs-0.0.19-desktop-category.patch
# PATCH-FIX-OPENSUSE qucs-digisim-verilog.patch -- using verilog for digital simulation by default
Patch1:         qucs-digisim-verilog.patch
BuildRequires:  adms
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gperf
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt4-devel
Requires:       adms
Requires:       asco
Requires:       iverilog
%lang_package

%description
Qucs is an integrated circuit simulator which means you are able to
setup a circuit with a graphical user interface (GUI) and simulate the
large-signal, small-signal and noise behaviour of the circuit. After
that simulation has finished you can view the simulation results on a
presentation page or window.

%package     -n libqucs0
Summary:        Qucs library
Group:          System/Libraries

%description -n libqucs0
This package contains the libqucs shared library.

%package        devel
Summary:        Development files fir QUCS library
Group:          Development/Libraries/Other
Requires:       libqucs0 = %{version}

%description    devel
This package contains the development files for Qucs.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
chmod -x CONTRIBUTING.md qucs/COPYING

%build
%configure --disable-doc
make %{?_smp_mflags}

%install
%make_install
%fdupes %{buildroot}/%{_datadir}/qucs/docs
rm %{buildroot}/%{_libdir}/libqucs.la

%post -n libqucs0 -p /sbin/ldconfig
%postun -n libqucs0 -p /sbin/ldconfig

%files
%doc CONTRIBUTING.md NEWS.md README.md
%license qucs/COPYING
%{_bindir}/ps2sp
%{_bindir}/qucs*
%{_datadir}/qucs/
%exclude %{_datadir}/qucs/lang
%{_datadir}/qucs-core/
%{_mandir}/man1/*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/qucs.*

%files -n libqucs0
%{_libdir}/libqucs.so.0*

%files devel
%{_libdir}/libqucs.so
%{_includedir}/qucs-core/

%files lang
%{_datadir}/qucs/lang

%changelog
* Sat Jun 23 2018 antoine.belvire@opensuse.org
- Update to version 0.0.19:
  * Update translations for various languages
  * Fix diagram color picker button (#30)
  * Fix zoom in a box (#31)
  * [NEW] Command line to save schematic as image (png, svg, pdf)
    (#32)
  * [NEW] Add component MutualX (#54)
  * [NEW] Enable anti-aliasing, provide it as option (#73)
  * [NEW] Add search file on component dock (PR#86)
  * Fix rendering of component text properties (PR#87, PR#98)
  * [NEW] Add recently opened menu (PR#95, PR#207)
  * Fix crash when loading timingdiagram (#112)
  * Refactor text search dialog (PR#124)
  * Correct simulator process exit check (#132)
  * Refactor project manager (PR#153)
  * Deprecated use of HOME environment variable (#204)
  * [NEW] Enable use of QUCSATOR environment variable to override
    qucsator (PR#209)
  * Fix bug on deactivation (short-circuiting) a component (#216)
  * Various usability enhancements (PR#232)
    + Adjust various dialogs for a better table sizing
    + Results of Optimization dialog can be copied to clipboard and
    pasted as an Equation
    + Fix usage of font metrics in the schematic
    + Fix handling of simulation messages in case a simulation is
    aborted
    + Add QT3_WARNINGS to serve as a reminder of which Qt3 stuff
    still needs removal
  * [NEW] Redesigned About dialog (PR#252)
  * Fix context menu texts when pressed over toolbar (#253)
  * Fix crash when using DC bias annotation with a simulation sweep
    (#272)
  * Selection of a wire label would change the font elsewhere in the
    schematic (#467)
  * Fix crash when changing background color (PR#456)
  * Changing in Qucs Home no longer requires a restart (PR#456)
  * Fix the "Open recent Files" which was not updated after save-as
    (PR#444)
  * Fix issue that allowed to create projects with an empty name
    (#311)
  * Update authors and date in the About dialog (PR#427)
  * Remove non-GPL Verilog-AMS models: HICUM, BSIM, FBH_HBT (#421)
  * Fix typo in Voltage Controlled Resistor (PR#406)
  * Fix keypad up/down on component dialog (#319)
  * Fix crash when reloading Verilog-A symbols (#478)
  * Fix matching circuit tool number conversion (PR#482)
  * Fix the handling of project names containing _prj in them
    (PR#486)
  * Remove usage of LANGUAGEDIR, LIBRARYDIR variables (PR#501,
    PR#508)
  * Enable loading unknown components, add sub-circuit place hoder
    (PR#507)
  * Fix "Export as image" behavior that was clipping markers on
    selected diagrams (PR#523)
  * Improve handling of Octave (PR#530)
    + removal of hardcoded path
    + override environment variable renamed from OCTAVEBINDIR to
    QUCS_OCTAVE
  * Fix "Move Up/Down" buttons greyed out in the equation property
    window (PR#548)
  * Fix Component search selecting wrong component (#543)
  * Fix cross-hair behavior of insert wire mode, related to
  zoom/scrool and RMB click (PR#504)
- Drop upstreamed/non-relevant-anymore patches:
  * qucs-0.0.18-gcc6.patch.
  * qucs-no-return-in-nonvoid-function.patch.
  * qucs_powerpc_gcc_undef_vector.patch.
- Use desktop file and icon provided by upstream:
  * Remove custom desktop file and icon from sources.
  * Add qucs-0.0.19-desktop-category.patch to respect openSUSE's
    desktop category guidelines.
- Clean spec file.
* Fri Jun 24 2016 i@marguerite.su
- add patch: qucs-0.0.18-gcc6.patch
  * fix boo#985097
  * fix call of overloaded 'abs(double&)' is ambiguous
* Tue Aug 11 2015 normand@linux.vnet.ibm.com
- for ppc64le archi add a new patch to avoid build error.
  qucs_powerpc_gcc_undef_vector.patch
* Wed Oct  1 2014 dmitry_r@opensuse.org
- Update to version 0.0.18
  * See NEWS.md for details
- Fix no-return-in-nonvoid-function
  * qucs-no-return-in-nonvoid-function.patch
* Thu Jul  4 2013 dmitry_r@opensuse.org
- Update to version 0.0.17
  * port to qt4
  * removed obsolete qucs-conj.diff
  * removed obsolete qucs-m4.diff
  * removed obsolete qucs-tr1.diff
* Tue Oct  2 2012 dmitry_r@opensuse.org
- Change license to "GPL-2.0 and GPL-2.0+" [bnc#783145]
* Sun Sep 30 2012 dmitry_r@opensuse.org
- Fix desktop file
- Fix SLE 11 build
* Sat Sep 29 2012 dmitry_r@opensuse.org
- Using verilog for digital simulation by default
  * qucs-digisim-verilog.patch
- Add desktop file
* Sat Aug 18 2012 dmitry_r@opensuse.org
- Spec file cleanup
- Fix buildrequires for openSUSE 12.2
* Sat Jun 25 2011 arun@gmx.de
- updated to 0.0.16
* Thu May 19 2011 stefan.bruens@rwth-aachen.de
- fix compilation and enhance spec file
* Sat Apr 25 2009 Werner Hoch <werner.ho@gmx.de>
- new version 0.0.15
* Mon Nov 24 2008 Werner Hoch <werner.ho@gmx.de>
- build fixes for factory
* Sun Apr 13 2008 Werner Hoch <werner.ho@gmx.de>
- new version 0.0.14
* Mon Dec 31 2007 Werner Hoch <werner.ho@gmx.de>
- new version 0.0.13
* Mon Jun 18 2007 Werner Hoch <werner.ho@gmx.de>
- new version 0.0.12
* Sun Mar 18 2007 Werner Hoch <werner.ho@gmx.de>
- new version 0.0.11
* Mon Oct 23 2006 Werner Hoch <werner.ho@gmx.de>
- initial build version 0.0.10
